Modules
Macros
- ensure_
same_ type - get_
type - kvar
- Shorthand macro for constructing TypeVar::Known
Structs
- Context
- Pipeline
State - Turbofish
Ctx - TypeMap
- Mapping between names and concrete type used for lookup, without being able to do more type inference Required because we can’t serde the whole TypeState
- Type
State - State of the type inference algorithm
Enums
- Generic
List Source - Generic
List Token - Stored version of GenericListSource