Enum expression::cond::Cond
[−]
[src]
pub enum Cond<E: Expression> { True, False, Not(Box<Cond<E>>), And(Box<Cond<E>>, Box<Cond<E>>), Or(Box<Cond<E>>, Box<Cond<E>>), Equal(Box<E>, Box<E>), Less(Box<E>, Box<E>), Greater(Box<E>, Box<E>), LessEqual(Box<E>, Box<E>), GreaterEqual(Box<E>, Box<E>), }
A boolean condition evaluates to either true or false.
Variants
TrueFalseNot(Box<Cond<E>>)And(Box<Cond<E>>, Box<Cond<E>>)Or(Box<Cond<E>>, Box<Cond<E>>)Equal(Box<E>, Box<E>)If two expressions are equal
Less(Box<E>, Box<E>)Greater(Box<E>, Box<E>)LessEqual(Box<E>, Box<E>)GreaterEqual(Box<E>, Box<E>)Trait Implementations
impl<E: Debug + Expression> Debug for Cond<E>[src]
impl<E: Clone + Expression> Clone for Cond<E>[src]
fn clone(&self) -> Cond<E>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<E: PartialEq + Expression> PartialEq for Cond<E>[src]
fn eq(&self, __arg_0: &Cond<E>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Cond<E>) -> bool
This method tests for !=.
impl<E: Expression> Condition for Cond<E>[src]
type Expr = E
fn evaluate(
&self,
variables: &[<Self::Expr as Expression>::Element]
) -> Result<bool, ExpressionError>
&self,
variables: &[<Self::Expr as Expression>::Element]
) -> Result<bool, ExpressionError>
Evaluate the condition with the given variables bound.
impl<'a, E, T> Into<Sexp> for &'a Cond<E> where
E: Expression<Element = T>,
&'a E: Into<Sexp>,
T: Debug + Copy + Clone + PartialEq + PartialOrd, [src]
E: Expression<Element = T>,
&'a E: Into<Sexp>,
T: Debug + Copy + Clone + PartialEq + PartialOrd,